@@ -3,16 +3,25 @@ package File::Copy::Link;
 use strict;
 use Carp;
 use File::Copy ();
-use File::Spec::Link ();
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(copylink);
-our $VERSION = '0.01';
+our @EXPORT_OK = qw(safecopylink);
+our $VERSION = '0.02';
 
 sub copylink(;$) {
     local $_ = @_ ? shift : $_;			# default to $_ 
     croak "$_ not a link\n" unless -l;
+    open my $fh, '<', $_ or croak "Can't open link $_: $!\n"; 
+    unlink or croak "Can't unlink link $_: $!\n";
+    File::Copy::copy $fh, $_ or croak "copy($fh $_) failed: $!\n";
+}
+
+sub safecopylink(;$) {
+    local $_ = @_ ? shift : $_;			# default to $_ 
+    croak "$_ not a link\n" unless -l;
+    require File::Spec::Link;
     my $orig = File::Spec::Link->linked($_);
     croak "$_ link problem\n" unless defined $orig;
     unlink or croak "Can't unlink link $_: $!\n";
@@ -33,10 +42,19 @@ linked file.
   use File::Copy::Link;
   copylink 'file.lnk'; 
 
+  use File::Copy::Link qw(safecopylink);
+  safecopylink 'file.lnk'; 
+
 =head1 DESCRIPTION
 
 C<copylink> reads the filename linked to by the argument and replaced 
-the link with a copy of the file.
+the link with a copy of the file.  It opens a filehandle to read from
+the link, deletes the link, and then copies the filehandle back to the
+link.
+
+C<safecopylink> does the same as C<copylink> but without the open-and-delete
+manouvre.  Instead, it uses C<File::Spec::Link> to find the target of the
+link and copies from there.
 
 This module is mostly a wrapper round C<File::Spec::Link::linked> and 
 C<File::Copy::copy>, the functionality is available in a command line
@@ -44,7 +62,7 @@ script F<copylink>.
  
 =head2 EXPORT
 
-C<copylink> - only sub defined 
+C<copylink> by default, can also export C<safecopylink>.
 
 =head1 SEE ALSO
 
